@@ -1,9 +1,8 @@
 /* See LICENSE file for copyright and license details. */
 
 /* appearance */
-#define BARPOS			BarTop /* BarBot, BarOff */
 #define BORDERPX		1
-#define FONT			"-*-terminus-medium-*-*-*-*-*-*-*-*-*-*-*"
+#define FONT			"-*-terminus-medium-r-normal-*-14-*-*-*-*-*-*-*"
 #define NORMBORDERCOLOR		"#cccccc"
 #define NORMBGCOLOR		"#cccccc"
 #define NORMFGCOLOR		"#000000"
@@ -12,24 +11,33 @@
 #define SELFGCOLOR		"#ffffff"
 
 /* tagging */
-const char tags[][MAXTAGLEN] = { "1", "2", "3", "4", "5", "6", "7", "8", "www" };
-Bool seltags[LENGTH(tags)] = {[0] = True};
+const char tags[][MAXTAGLEN] = { "1", "2", "3", "4", "5", "6", "7", "8", "9" };
+
 Rule rules[] = {
-	/* class:instance:title regex	tags regex	isfloating */
-	{ "Firefox",			"www",		False },
-	{ "Gimp",			NULL,		True },
-	{ "MPlayer",			NULL,		True },
-	{ "Acroread",			NULL,		True },
+	/* class	instance	title		tags ref	isfloating */
+	{ "Gimp",	NULL,		NULL,		NULL,		True },
+};
+
+/* geometries, s{x,y,w,h} and bh are already initualized here */
+/*   func name  bx  by  bw  wx  wy  ww     wh  mx  my       mw  mh     tx  ty     tw  th  mox moy mow moh */
+#define MFACT			0.55	/* master width factor [0.1 .. 0.9] */
+DEFGEOM(single,  0,  0, sw,  0, bh, sw, sh-bh, wx, wy, mfact*sw, wh, mx+mw, wy, ww-mw, wh,  wx, wy, ww, wh)
+
+Geom geoms[] = {
+	/* symbol	function */
+	{ "[]",		single },	/* first entry is default */
 };
 
 /* layout(s) */
-#define MWFACT			0.6	/* master width factor [0.1 .. 0.9] */
 #define RESIZEHINTS		True	/* False - respect size hints in tiled resizals */
 #define SNAP			32	/* snap pixel */
+
 Layout layouts[] = {
-	/* symbol		function */
-	{ "[]=",		tile }, /* first entry is default */
-	{ "><>",		floating },
+	/* symbol		function	isfloating */
+	{ "[]=",		tilev,		False }, /* first entry is default */
+	{ "[]|",		tileh,		False },
+	{ "><>",		floating,	True },
+	{ "[M]",		monocle,	True },
 };
 
 /* key definitions */
@@ -37,20 +45,19 @@ Layout layouts[] = {
 Key keys[] = {
 	/* modifier			key		function	argument */
 	{ MODKEY,			XK_p,		spawn,
-		"exe=`dmenu_path | dmenu -fn '"FONT"' -nb '"NORMBGCOLOR"' -nf '"NORMFGCOLOR"'"
-		" -sb '"SELBGCOLOR"' -sf '"SELFGCOLOR"'` && exec $exe" },
-	{ MODKEY|ShiftMask,		XK_Return,	spawn, "exec uxterm" },
-	{ MODKEY,			XK_space,	setlayout,	NULL },
-	{ MODKEY,			XK_b,		togglebar,	NULL },
+		"exec dmenu_run -fn '"FONT"' -nb '"NORMBGCOLOR"' -nf '"NORMFGCOLOR"' -sb '"SELBGCOLOR"' -sf '"SELFGCOLOR"'" },
+	{ MODKEY|ShiftMask,		XK_Return,	spawn,		"exec uxterm" },
 	{ MODKEY,			XK_j,		focusnext,	NULL },
 	{ MODKEY,			XK_k,		focusprev,	NULL },
-	{ MODKEY,			XK_h,		setmwfact,	"-0.05" },
-	{ MODKEY,			XK_l,		setmwfact,	"+0.05" },
-	{ MODKEY,			XK_m,		togglemax,	NULL },
+	{ MODKEY,			XK_r,		reapply,	NULL },
+	{ MODKEY,			XK_h,		setmfact,	"-0.05" },
+	{ MODKEY,			XK_l,		setmfact,	"+0.05" },
 	{ MODKEY,			XK_Return,	zoom,		NULL },
 	{ MODKEY,			XK_Tab,		viewprevtag,	NULL },
-	{ MODKEY|ShiftMask,		XK_space,	togglefloating,	NULL },
 	{ MODKEY|ShiftMask,		XK_c,		killclient,	NULL },
+	{ MODKEY,			XK_space,	setlayout,	NULL },
+	{ MODKEY|ShiftMask,		XK_space,	togglefloating,	NULL },
+	{ MODKEY|ControlMask,		XK_space,	setgeom,	NULL },
 	{ MODKEY,			XK_0,		view,		NULL },
 	{ MODKEY,			XK_1,		view,		tags[0] },
 	{ MODKEY,			XK_2,		view,		tags[1] },
